# OAPILib

## description

TBD

## Notes

api.py
------

# import sys


# from .util import StreamToLogger, jsonify

# sys.stdout = StreamToLogger()


client.py
---------

# from httpx.models import BaseResponse

# from typing_extensions import Literal

cli/config.py
---------

# import sys

# from loguru import logger

core/config.py
--------------
